/*
 * Properties
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 17, 2001
 */

package com.omh;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Stack;
import java.util.Date;
import java.util.EmptyStackException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

/**
 * Simple servlet that gets the current date and time. Uses a simple
 * cache (a Stack) for the Date objects.
 */
public class GetDate
        extends HttpServlet
{
    // The cache of Date objects
    Stack dateCache = new Stack();

    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, IOException
    {
        // Get an output stream that takes into account
        // the proper character encoding
        PrintWriter out = resp.getWriter();

        // Print the HTML header to the output stream
        out.println("<html>");
        out.println("<head>");
        out.println("<title>The Server Date</title>");
        out.println("</head>");
        out.println("<h2>");

        // Get a DateFormat from the cache
        DateFormat dateFormat = getDateFormat();
        String now = dateFormat.format(new Date());

        out.println("The date/time on the server is: " + now);
        out.println("<br>");

        // We're done with the DateFormat. Put it back
        putDateFormat(dateFormat);

        // Wrap up
        out.println("</html>");
        out.flush();
    }

    /**
     * Get a DateFormat object from the cache. If one does not
     * exist, create a new one
     */
    public DateFormat getDateFormat()
    {
        DateFormat dateFormat = null;
        try
        {
            dateFormat = (DateFormat) dateCache.pop();
        }
        catch (EmptyStackException ex)
        {
            // Create a new Date object if the stack is empty
            dateFormat = new SimpleDateFormat("yyyy.MM.dd hh:mm:ss z");
        }
        return dateFormat;
    }

    /**
     * Puts the DateFormat object back into the cache
     */
    public void putDateFormat(DateFormat dateFormat)
    {
        dateCache.push(dateFormat);
    }
}
