/*
 * ColumnDesc
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 23, 2001
 */

package com.omh.db;

import java.sql.*;

/**
 * This class represents a single column description
 */

public class ColumnDesc
{
    String columnName;
    int columnType;
    int columnLength;
    int columnDecimals;

    /**
     * Construct a new column descriptor
     *
     * @param name Column name
     * @param type JDBC column type
     */
    public ColumnDesc(String name, int type)
    {
        this(name, type, -1, -1);
    }

    /**
     * Construct a new column descriptor
     *
     * @param name Column name
     * @param type JDBC column type
     * @param len Maximumn column length
     */
    public ColumnDesc(String name, int type, int len)
    {
        this(name, type, len, -1);
    }

    /**
     * Construct a new column descriptor
     *
     * @param name Column name
     * @param type JDBC column type
     * @param len Maximumn column length
     * @param decimals Number of decimal places
     */
    public ColumnDesc(String name, int type, int len, int decimals)
    {
        columnName = name;
        columnType = type;
        columnLength = len;
        columnDecimals = decimals;
    }

    /**
     * Sets the column name
     *
     * @param name Column name
     */
    public void setName(String name)
    {
        columnName = name;
    }

    /**
     * Gets the column name
     *
     * @return Column name
     */
    public String getName()
    {
        return columnName;
    }

    /**
     * Sets the column type
     *
     * @param type JDBC column type
     */
    public void setType(int type)
    {
        columnType = type;
    }

    /**
     * Gets the column type
     *
     * @return JDBC column type
     */
    public int getType()
    {
        return columnType;
    }

    /**
     * Sets the length of the column
     *
     * @param len Length of the column
     */
    public void setLength(int len)
    {
        columnLength = len;
    }

    /**
     * Gets the length of the column
     *
     * @return Length of the column, or -1 for not applicable
     */
    public int getLength()
    {
        return columnLength;
    }

    /**
     * Sets the number of decimal places for the column
     *
     * @param dec Number of decimal places
     */
    public void setDecimals(int dec)
    {
        columnDecimals = dec;
    }

    /**
     * Gets the number of decimal places for the column
     *
     * @return Number of decimal places, or -1 for not
     * applicable
     */
    public int getDecimals()
    {
        return columnDecimals;
    }
}
