/*
 * ImageServer
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 24, 2001
 */

package com.omh.db;

import com.omh.jdbc.ConnectionPool;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.sql.*;

/**
 * This servlet will query the database for a stored binary
 * image, read it, and return it to the client.
 */

public class ImageServer
        extends HttpServlet
{
    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
            throws ServletException, IOException
    {
        // Get the table to query
        String tableName = req.getParameter("table");

        // Get the column to query
        String columnName = req.getParameter("column");

        // Get the 'where' clause for the query
        String whereClause = req.getParameter("where");

        // Attempt to get the image
        getImage(resp, tableName, columnName, whereClause);
    }

    /**
     * Reads the database for an image and outputs that image
     * to the client
     *
     * @param resp The response from the servlet
     * @param table The name of the table containing the data
     * @param column The column name of the stored image
     * @param where The SQL where clause to uniquely identify
     * the row
     */
    private void getImage(HttpServletResponse resp,
                          String table, String column,
                          String where)
            throws IOException
    {
        // Our connection pool
        ConnectionPool pool = null;

        // Format the SQL string
        String sql = "select " + column + " from " + table +
                     " where " + where;

        // The JDBC Connection object
        Connection con = null;

        // The JDBC Statement object
        Statement stmt = null;

        // The JDBC ResultSet object
        ResultSet rs = null;

        try
        {

            // Get an available connection from our connection pool
            ServletContext context = getServletContext();
            String key = ConnectionServlet.CONNECTION_POOL_KEY;
            Object o = context.getAttribute(key);

            // Should sanity-check here to ensure the pool is
            // not null and is the correct type of object
            pool = (ConnectionPool) o;

            // Get an available connection from our connection pool
            con = pool.getConnection();

            // Create a statement object that we can execute queries
            // with
            stmt = con.createStatement();

            // Execute the query
            rs = stmt.executeQuery(sql);

            // If this is an empty result set, send back a nice
            // error message
            if (!rs.next())
            {
                resp.setContentType("text/html");

                PrintWriter pout = resp.getWriter();

                pout.println("No matching record found");
                pout.flush();
                pout.close();
            }

            // We have results! Read the image and write it to
            // our output stream
            resp.setContentType("image/gif");

            // Get the output stream
            ServletOutputStream out = resp.getOutputStream();

            // Get an input stream to the stored image
            InputStream in = rs.getBinaryStream(1);

            // Some database systems may not be able to tell us
            // how big the data actuall is. Let's read all of it
            // into a buffer.
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            byte b[] = new byte[1024];
            while (true)
            {
                int bytes = in.read(b);

                // If there was nothing read, get out of loop
                if (bytes == -1)
                {
                    break;
                }

                // Write the buffer to our byte array
                baos.write(b, 0, bytes);
            }

            // Now we have the entire image in the buffer. Get
            // the length and write it to the output stream
            b = baos.toByteArray();

            resp.setContentLength(b.length);
            out.write(b, 0, b.length);
            out.flush();
            out.close();
        }
        catch (Exception ex)
        {
            // Set the content type of the response
            resp.setContentType("text/html");

            PrintWriter pout = resp.getWriter();

            pout.println("Exception!");
            ex.printStackTrace(pout);
            pout.flush();
            pout.close();
        }
        finally
        {
            try
            {
                // Always close properly
                if (rs != null)
                {
                    rs.close();
                }
                if (stmt != null)
                {
                    stmt.close();
                }
                if (con != null)
                {
                    // Put the connection back into the pool
                    pool.close(con);
                }
            }
            catch (Exception ex)
            {
                // Ignore any errors here
            }
        }
    }
}

