/*
 * CharResponseWrapper
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 25, 2001
 */

package com.omh.filters;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * Simple response wrapper that utilizes a local CharArrayWriter
 * for output
 */
public class CharResponseWrapper
        extends HttpServletResponseWrapper
{
    protected CharArrayWriter charWriter;
    protected PrintWriter writer;
    protected boolean getOutputStreamCalled;
    protected boolean getWriterCalled;

    public CharResponseWrapper(HttpServletResponse response)
    {
        super(response);

        // Create the writer
        charWriter = new CharArrayWriter();
    }

    public ServletOutputStream getOutputStream()
        throws IOException
    {
        // Can't call getOutputStream if getWriter
        // has already been called
        if (getWriterCalled)
        {
            throw new IllegalStateException(
                    "getWriter already called");
        }

        getOutputStreamCalled = true;
        return super.getOutputStream();
    }

    public PrintWriter getWriter()
        throws IOException
    {
        if (writer != null)
        {
            return writer;
        }

        // Can't call getWriter if getOutputStream
        // has already been called
        if (getOutputStreamCalled)
        {
            throw new IllegalStateException(
                    "getOutputStream already called");
        }
        getWriterCalled = true;
        writer = new PrintWriter(charWriter);
        return writer;
    }

    public String toString()
    {
        String s = null;

        // Only return a String if the writer was
        // used.
        if (writer != null)
        {
            s = charWriter.toString();
        }
        return s;
    }
}
