/*
 * ResponseTimerFilter
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 25, 2001
 */

package com.omh.filters;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * Simple filter for measuring servlet response times
 */
public class ResponseTimerFilter
        implements Filter
{
    protected FilterConfig config;

    public void init(FilterConfig config)
        throws ServletException
    {
        // Save the config object
        this.config = config;
    }

    public void destroy()
    {
    }

    public void doFilter(ServletRequest request,
                         ServletResponse response,
                         FilterChain chain)
        throws ServletException, IOException
    {
        // Save the start time
        long startTime = System.currentTimeMillis();

        // Invoke the next filter/servlet in the chain
        chain.doFilter(request, response);

        // Capture the elapsed time
        long elapsed = System.currentTimeMillis() - startTime;

        // Figure out what was requested. If we are not
        // processing an HTTP request just default the
        // name to servlet
        String name = "servlet";
        if (request instanceof HttpServletRequest)
        {
            name = ((HttpServletRequest) request).getRequestURI();
        }

        // Output the time
        config.getServletContext().log(name +
                " took " + elapsed + " ms");
    }
}
