/*
 * UpperCaseFilter
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 25, 2001
 */

package com.omh.filters;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * Filter that uses a response wrapper to convert all
 * output to upper case
 */
public class UpperCaseFilter
        implements Filter
{
    protected FilterConfig config;

    public void init(FilterConfig config)
        throws ServletException
    {
        // Save the config object
        this.config = config;
    }

    public void destroy()
    {
    }

    public void doFilter(ServletRequest request,
                         ServletResponse response,
                         FilterChain chain)
        throws ServletException, IOException
    {
        ServletResponse newResponse = response;

        // If this is an HttpRequest, wrap the response
        // with our CharArrayWriter so that we can get
        // the contents
        if (request instanceof HttpServletRequest)
        {
            newResponse = new CharResponseWrapper(
                    (HttpServletResponse) response);
        }

        // Invoke the next filter/servlet in the chain
        // using (perhaps) a wrapped response
        chain.doFilter(request, newResponse);

        if (newResponse instanceof CharResponseWrapper)
        {
            // Get the contents of the output. A String
            // is returned only if a Writer was used,
            // indicating text output. If getOutputStream
            // was used the output will go to the "real"
            // underlying output stream back to the client
            String text = newResponse.toString();
            if (text != null)
            {
                text = text.toUpperCase();

                // Now write the output to the real
                // output stream that goes back to
                // the client
                response.getWriter().write(text);
            }
        }
    }

}
