/*
 * ConnectionObject
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 23, 2001
 */

package com.omh.jdbc;

import java.sql.*;

/**
 * Represents a single connection object which is stored
 * in a connection pool
 */
public class ConnectionObject
{
    // The JDBC Connection
    protected Connection con;

    // true if this connection is currently in use
    protected boolean inUse;

    // The last time (in milliseconds) that this connection was used
    protected long lastAccess;

    // The number of times this connection has been used
    protected int useCount;

    public boolean isInUse()
    {
        return inUse;
    }

    public int getUseCount()
    {
        return useCount;
    }

    public long getLastAccess()
    {
        return lastAccess;
    }

    /**
     * Determine if the connection is available
     *
     * @return true if the connection can be used
     */
    public boolean isAvailable()
    {
        boolean available = false;

        try
        {
            // To be available, the connection cannot be in use
            // and must be open
            if (con != null)
            {
                if (!inUse &&
                    !con.isClosed())
                {
                    available = true;
                }
            }
        }
        catch (Exception ex)
        {
        }

        return available;
    }

    /**
     * Convert the object contents to a String
     */
    public String toString()
    {
        return "Connection=" + con + ",inUse=" + inUse +
               ",lastAccess=" + lastAccess + ",useCount=" + useCount;
    }
}
