/*
 * MyContextAttributeListener
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 2, 2001
 */

package com.omh.listeners;

import javax.servlet.ServletContextAttributeListener;
import javax.servlet.ServletContextAttributeEvent;
import javax.servlet.ServletContext;

/**
 * Simple example of implementing the application lifecycle
 * event listener ServletContextAttributeListener
 */
public class MyContextAttributeListener
        implements ServletContextAttributeListener
{
    public void attributeAdded(ServletContextAttributeEvent event)
    {
        // Grab ahold of the ServletContext
        ServletContext context = event.getServletContext();

        String attributeName = event.getName();
        Object attributeValue = event.getValue();

        context.log("Add context attribute " +
                    attributeName + "=" + attributeValue);
    }

    public void attributeRemoved(ServletContextAttributeEvent event)
    {
        // Grab ahold of the ServletContext
        ServletContext context = event.getServletContext();

        String attributeName = event.getName();
        Object attributeValue = event.getValue();

        context.log("Remove context attribute " +
                    attributeName + "=" + attributeValue);
    }

    public void attributeReplaced(ServletContextAttributeEvent event)
    {
        // Grab ahold of the ServletContext
        ServletContext context = event.getServletContext();

        String attributeName = event.getName();
        Object oldAttributeValue = event.getValue();
        Object attributeValue =
                context.getAttribute(attributeName);

        context.log("Replace context attribute " +
                    attributeName + "=" + attributeValue +
                    " old value=" + oldAttributeValue);
    }
}
