/*
 * MySessionAttributeListener
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 2, 2001
 */

package com.omh.listeners;

import javax.servlet.*;
import javax.servlet.http.*;

/**
 * Simple example of implementing the application lifecycle
 * event listener HttpSessionAttributeListener
 */
public class MySessionAttributeListener
        implements HttpSessionAttributeListener
{
    public void attributeAdded(HttpSessionBindingEvent event)
    {
        // Get the session
        HttpSession session = event.getSession();

        // Grab ahold of the ServletContext
        ServletContext context = session.getServletContext();

        String sessionId = session.getId();
        String attributeName = event.getName();
        Object attributeValue = event.getValue();

        context.log("Add session " + sessionId +
                    " attribute " +
                    attributeName + "=" + attributeValue);
    }

    public void attributeRemoved(HttpSessionBindingEvent event)
    {
        // Get the session
        HttpSession session = event.getSession();

        // Grab ahold of the ServletContext
        ServletContext context = session.getServletContext();

        String sessionId = session.getId();
        String attributeName = event.getName();
        Object attributeValue = event.getValue();

        context.log("Remove session " + sessionId +
                    " attribute " +
                    attributeName + "=" + attributeValue);
    }

    public void attributeReplaced(HttpSessionBindingEvent event)
    {
        // Get the session
        HttpSession session = event.getSession();

        // Grab ahold of the ServletContext
        ServletContext context = session.getServletContext();

        String sessionId = session.getId();
        String attributeName = event.getName();
        Object oldAttributeValue = event.getValue();
        Object attributeValue =
                session.getAttribute(attributeName);

        context.log("Replace session " + sessionId +
                    " attribute " +
                    attributeName + "=" + attributeValue +
                    " old value=" + oldAttributeValue);
    }

}
