/*
 * IndyMIDlet
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Dec 14, 2001
 */

package com.omh.micro;

import javax.microedition.midlet.MIDlet;
import javax.microedition.lcdui.*;
import javax.microedition.io.HttpConnection;

public class IndyMIDlet
        extends MIDlet
        implements CommandListener
{
    // User interface command to exit the current application
    private Command exitCommand  = new Command("Exit", Command.EXIT, 2);

    // User interface command to confirm current operation
    private Command okCommand = new Command("OK", Command.OK, 1);

    // The year to fetch
    int year = 2001;

    // The text box used to query the winner
    private TextBox getWinner;

    // Our remote indy object
    private IndyInterface remoteIndy;

    /**
     * Start creates the thread to do the timing.
     * It should return immediately to keep the dispatcher
     * from hanging.
     */
    public void startApp()
    {
        mainScreen();
    }

    /**
     * Destroy must cleanup everything.  The thread is signaled
     * to stop and no result is produced.
     * @param unconditional Flag to indicate that forced shutdown
     * is requested
     */
    public void destroyApp(boolean unconditional)
    {
        if (remoteIndy != null)
        {
            try
            {
                remoteIndy.close();
            }
            catch (Exception ex)
            {
                displayMessage("Error", ex.getMessage());
            }
        }
    }

    /**
     * Pause signals the thread to stop by clearing the thread field.
     * If stopped before done with the iterations it will
     * be restarted from scratch later.
     */
    public void pauseApp()
    {
    }

    /**
     * Display the main screen.
     */
    void mainScreen()
    {
        String s = "Press OK to fetch the winner of the " +
                    year + " Indianapolis 500";

        getWinner = new TextBox("Indy Winners", s, s.length(), 0);

        getWinner.addCommand(okCommand);
        getWinner.addCommand(exitCommand);
        getWinner.setCommandListener(this);
        Display.getDisplay(this).setCurrent(getWinner);
    }

    /**
     * Display an error
     */
    protected void displayMessage(String title, String msg)
    {
        TextBox tb = new TextBox(title, msg, msg.length(), 0);

        tb.addCommand(okCommand);
        tb.setCommandListener(this);
        Display.getDisplay(this).setCurrent(tb);
    }

    /**
     * Request the winner through our remote object
     */
    protected void requestWinner()
    {
        if (remoteIndy == null)
        {
            // Instantiate a new remote object
            String url = "http://localhost:8080/jsdg-micro";
            try
            {
                remoteIndy = new RemoteIndyMicroClient(url);

                // Connect to the database
                remoteIndy.connect();
            }
            catch (Exception ex)
            {
                displayMessage("Error", ex.getMessage());
            }
        }

        if (remoteIndy != null)
        {
            try
            {
                IndyRecord record = remoteIndy.query(year);
                String msg = "The winner in " + record.year +
                             " was " + record.driver +
                             " at " + record.speed + "mph";
                displayMessage("Results", msg);
            }
            catch (Exception ex)
            {
                displayMessage("Error", ex.getMessage());
            }
        }
    }

    /**
     * Respond to commands, including exit
     * @param c command to perform
     * @param s Screen displayable object
     */
    public void commandAction(Command c, Displayable s)
    {
        if (c == exitCommand)
        {
            destroyApp(false);
            notifyDestroyed();
        }
        else if (c == okCommand)
        {
            if (s == getWinner)
            {
                requestWinner();
            }
            else
            {
                // User pressed 'ok' from results page. Go
                // back to the main screen
                mainScreen();
            }
        }
    }
}
