/*
 * RemoteIndyMicroClient
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Dec 14, 2001
 */

package com.omh.micro;

import com.omh.micro.client.MicroTunnelClient;
import com.omh.micro.client.TunnelException;
import java.io.*;

public class RemoteIndyMicroClient
        extends MicroTunnelClient
        implements IndyInterface
{
    /**
     * Constructs a new RemoteMathLiteClient for the
     * given URL. The URL should contain the location of
     * servlet scripts (i.e. http://larryboy/servlet/).
     */
    public RemoteIndyMicroClient(String url)
        throws TunnelException, IOException
    {
        // Append the remote server name
        if (!url.endsWith("/"))
        {
            url += "/";
        }
        url += "RemoteIndyMicroServer";

        // Set the URL
        _setURL(url);

        // Initialize the client and server
        _initialize();
    }

    public boolean connect()
    {
        boolean rc = false;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an object stream to write the request
            DataOutputStream out = _createHeader(baos, 0);

            // Invoke the method and read the response
            DataInputStream in = _invokeMethod(baos.toByteArray());

            // Read the return value
            rc = in.readBoolean();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }

        return rc;
    }

    public void close()
    {
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an object stream to write the request
            DataOutputStream out = _createHeader(baos, 1);

            // Invoke the method
            _invokeMethod(baos.toByteArray());

            // Wrap up
            out.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    public IndyRecord query(int year)
    {
        IndyRecord record = null;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an object stream to write the request
            DataOutputStream out = _createHeader(baos, 2);

            // Write the parameters
            out.writeInt(year);

            // Invoke the method and read the response
            DataInputStream in = _invokeMethod(baos.toByteArray());

            // Read the return value
            record = new IndyRecord();
            record.year = in.readInt();
            record.driver = in.readUTF();
            record.speed = in.readUTF();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }

        return record;
    }
}
