/*
 * RemoteIndyMicroServer
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Dec 14, 2001
 */

package com.omh.micro;

import com.omh.tunnel.server.TunnelLiteServer;
import com.omh.tunnel.Indy;
import com.omh.tunnel.IndyRecord;
import javax.servlet.ServletException;
import java.io.*;

public class RemoteIndyMicroServer
        extends TunnelLiteServer
{
    /**
     * Creates a new instance of the server object.
     *
     * @return Instance of the server object
     */
    public Object _getNewInstance()
        throws ServletException
    {
        return new Indy();
    }

    /**
     * Invokes the method for the ordinal given. If the method
     * throws an exception it will be sent to the client.
     *
     * @param Object Server object
     * @param ordinal Method ordinal
     * @param in Input stream to read additional parameters
     * @param out Output stream to write return values
     */
    public void _invokeMethod(Object serverObject, int ordinal,
                              DataInput in, DataOutput out)
        throws Exception
    {
        // Cast the server object
        Indy indy = (Indy) serverObject;

        // Cast the input/output streams
        DataInputStream dataIn = (DataInputStream) in;
        DataOutputStream dataOut = (DataOutputStream) out;

        // Evaluate the ordinal
        switch (ordinal)
        {

        case 0: // connect
            boolean b0 = indy.connect();
            dataOut.writeBoolean(b0);
            break;

        case 1: // close
            indy.close();
            break;

        case 2: // query
            int i2 = dataIn.readInt();
            IndyRecord record = indy.query(i2);
            dataOut.writeInt(record.year);
            dataOut.writeUTF(record.driver);
            dataOut.writeUTF("" + record.speed);
            break;

        default:
            throw new Exception("Invalid ordinal: " + ordinal);
        }
    }
}
