/*
 * DataSourceList
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Dec 27, 2001
 */

package com.omh.nativeCode;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * This servlet uses native code to gather a list of the
 * current ODBC data sources.
 */
public class DataSourceList
        extends HttpServlet
{
    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
    throws ServletException, IOException
    {
        // Set the content type of the response
        resp.setContentType("text/html");

        // Get the PrintWriter to write the response
        PrintWriter out = resp.getWriter();

        // Create the header
        out.println("<html>");
        out.println("<head>");
        out.println("<title>ODBC Data Source List</title>");
        out.println("</head>");
        out.println("<body><center>");
        out.println("<h2>ODBC Data Sources Available To Servlets " +
                    "Running in the Current Servlet Container</h2>");
        out.println("<br>");
        out.println("<table border>");
        out.println("<tr><th>Data Source Name</th>");
        out.println("<th>Description</th></tr>");

        int henv = 0;

        try
        {
            // Allocate an environment handle
            henv = JavaToODBC.SQLAllocEnv();
        }
        catch (Exception ex)
        {
            out.println("ERROR: Unable to allocate environment");
        }

        // Loop through the data sources until the end of file
        // is reached
        while (true)
        {
            // Create a new DataSource object to hold the
            // data source attributes (name, description)
            DataSource ds = new DataSource();
            boolean b = false;

            try
            {
                // Make a native ODBC call to get the next data source
                // entry. The first call will return the first data source;
                // any subsequent calls will return the next data source
                b = JavaToODBC.SQLDataSources(henv, ds);
            }
            catch (Exception ex)
            {
                ex.printStackTrace();
                out.println("</table><br>ERROR: " + ex.getMessage());
                break;
            }

            // SQLDataSources returns false if there are no more
            // data sources
            if (!b)
            {
                break;
            }

            // Add this data source to the table
            out.println("<tr><td>" + ds.getName() +
                        "</td><td>" + ds.getDescription() + "</td></tr>");
        }

        if (henv != 0)
        {
            try
            {
                // Free the environment handle
                JavaToODBC.SQLFreeEnv(henv);
            }
            catch (Exception ex)
            {
                // Ignore any errors
            }
        }

        // Wrap up
        out.println("</table></center>");
        out.println("</body>");
        out.println("</html>");
        out.flush();
    }
}

