/*
 * HelloWorld
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Dec 20, 2001
 */

package com.omh.nativeCode;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;
import java.io.PrintWriter;

/**
 * This servlet uses native code to get a "Hello World" message
 */
public class HelloWorld
        extends HttpServlet
{
    /**
     * Use a static initializer to load the native code which
     * is contained within a library. This initializer is
     * called when the class loader first loads this class.
     */
    static
    {
        System.out.println("Loading HelloWorld Library");
        System.loadLibrary("HelloWorld");
    }

    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, IOException
    {
        // Set the content type of the response
        resp.setContentType("text/html");

        // Get the PrintWriter to write the response
        PrintWriter out = resp.getWriter();

        // Create the header
        out.println("<html>");
        out.println("<head>");
        out.println("<title>Hello World Using Native Code</title>");
        out.println("</head>");
        out.println("<body><center>");
        out.println("Native code returning: " + getMessage());
        out.println("<br><br>");
        out.println("Native code inserts: ");
        printMessage(out);

        // Wrap up
        out.println("</body>");
        out.println("</html>");
        out.flush();
    }

    /**
     * Gets a message from a native library
     * @return A message
     */
    public native String getMessage();

    /**
     * Prints a message to the print stream
     * @param out The print stream
     */
    public native void printMessage(PrintWriter out);

}

