/*
 * JavaToODBC
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Dec 20, 2001
 */

package com.omh.nativeCode;

/**
 * This class defines all of the native methods used to bridge
 * from Java to ODBC.
 */
public class JavaToODBC
{
    /**
     * Use a static initializer to load the native code which
     * is contained within a library. This initializer is
     * called when the class loader first loads this class.
     */
    static
    {
        System.out.println("Loading JavaToODBC Library");
        System.loadLibrary("JavaToODBC");
    }

    /**
     * Creates an environment handle and initializes the ODBC
     * call level interface. SQLAllocEnv <b>must</b> be called
     * prior to calling any other ODBC functions.
     * @return The environment handle
     */
    public static native int SQLAllocEnv() throws Exception;

    /**
     * Frees the environment handle and releases all memory
     * associated with the environment handle
     * @param The environment handle
     */
    public static native void SQLFreeEnv(int henv) throws Exception;

    /**
     * Returns information about the next data source. The first
     * time this method is called the first data source will
     * be used; any subsequent calls will return the next data
     * source.
     * @param henv The environment handle
     * @param dataSource The DataSource object which will hold
     * the information for the data source
     * @return true if the data source is valid; false if no more
     * data source names were found
     */
    public static native boolean SQLDataSources(int henv, DataSource ds)
        throws Exception;
}

