/*
 * ScheduledRunnable
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 31, 2001
 */

package com.omh.scheduler;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;

/**
 * Represents a single scheduled Runnable object
 */
public class ScheduledRunnable
{
    // Keep a weak reference to the Runnable so that
    // we don't prevent the garbage collector from
    // reclaiming it
    protected Reference runnable;

    // The time at which the Runnable should run
    protected long time;

    public ScheduledRunnable(Runnable r, long time)
    {
        this.runnable = new WeakReference(r);
        this.time = time;
    }

    /**
     * Gets the Runnable object, or null if the Runnable is
     * no longer valid
     */
    public Runnable getRunnable()
    {
        return (Runnable) runnable.get();
    }

    public long getTime()
    {
        return time;
    }
}
