/*
\ * AppletLogin
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 22, 2001
 */

package com.omh.security;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Hashtable;

/**
 * This servlet creates an HTML page that will present an
 * applet that gathers the username and password. This servlet
 * will also validate the input and redirect the applet as
 * necessary.
 */
public class AppletLogin
        extends HttpServlet
{
    public static String USER_KEY = "ServletLogin.user";

    // Keep a cross reference of usernames to session id's
    static Hashtable crossRef = new Hashtable();

    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, java.io.IOException
    {
        // Set the content type of the response
        resp.setContentType("text/html");

        // Get the PrintWriter to write the response
        PrintWriter out = resp.getWriter();

        // Set the response header to force the browser to
        // load the HTML page from the server instead of
        // from a cache
        resp.setHeader("Expires",
                       "Tues, 01 Jan 1980 00:00:00 GMT");

        // Get the current user. If one does not exist, create
        // a form to gather the user and password
        HttpSession session = req.getSession();
        String user = (String) session.getAttribute(USER_KEY);

        if (user == null)
        {
            // Check our cross-reference table
            user = (String) crossRef.get(session.getId());

            if (user != null)
            {
                // Found the user in the cross reference table.
                // Put the user in this session and remove from
                // the table
                session.setAttribute(USER_KEY, user);
                crossRef.remove(session.getId());
            }
        }

        if (user == null)
        {
            // No user - create the form to prompt the user
            login(out, req, resp);
            return;
        }

        // Print a standard header
        out.println("<html>");
        out.println("<head>");
        out.println("<title>Wecome</title>");
        out.println("</head>");
        out.println("<body>");
        out.println("<center><h2>Welcome to our site!</h2>");
        out.println("<br>");
        out.println("More cool stuff coming soon...");
        out.println("</center>");

        // Wrap up
        out.println("</body>");
        out.println("</html>");
        out.flush();
    }

    public void doPost(HttpServletRequest req,
                       HttpServletResponse resp)
        throws ServletException, java.io.IOException
    {
        // Get the input stream for reading data from the client
        DataInputStream in =
            new DataInputStream(req.getInputStream());

        // We'll be sending binary data back to the client so
        // set the content type appropriately
        resp.setContentType("application/octet-stream");

        // Data will always be written to a byte array buffer so
        // that we can tell the client the length of the data
        ByteArrayOutputStream byteOut =
            new ByteArrayOutputStream();

        // Create the output stream to be used to write the
        // data to our buffer
        DataOutputStream out =
            new DataOutputStream(byteOut);

        // Read the proper session id
        String sessionId = in.readUTF();

        // Read the username and password
        String user = in.readUTF();
        String password = in.readUTF();

        // May want to decrypt the user and/or password here

        // Validate the user
        if (!validUser(user, password))
        {
            // Send back a boolean value indicating that the
            // user is invalid
            out.writeBoolean(false);
        }
        else
        {
            // User valid. Set the user in our cross-reference table
            // and send back a boolean valid indicating that the user
            // is valid
            crossRef.put(sessionId, user);
            out.writeBoolean(true);

            // Write the location of the next page
            String nextPage = req.getScheme() + "://" +
                req.getServerName() + ":" +
                req.getServerPort() +
                req.getRequestURI();

            // Use URL rewriting for session info
            out.writeUTF(nextPage);
        }

        // Flush the contents of the output stream to the
        // byte array
        out.flush();

        // Get the buffer that is holding our response
        byte[] buf = byteOut.toByteArray();

        // Notify the client how much data is being sent
        resp.setContentLength(buf.length);

        // Send the buffer to the client
        ServletOutputStream servletOut = resp.getOutputStream();

        // Wrap up
        servletOut.write(buf);
        servletOut.close();
    }

    /**
     * Formats the login page
     * @param out The output stream to write the response to
     * @param uri The request
     */
    protected void login(PrintWriter out,
                         HttpServletRequest req,
                         HttpServletResponse resp)
        throws java.io.IOException
    {
        // Get the session
        HttpSession session = req.getSession();

        out.println("<html>");
        out.println("<head>");
        out.println("<title>Login</title>");
        out.println("<center><h2>Welcome! Please login</h2>");
        out.println("<applet width=200 height=120");
        out.println("   name=\"LoginApplet\"");
        out.println("   codebase=\"/\"");
        out.println("   code=\"com.omh.security.LoginApplet\">");
        out.println("<param name=\"servlet\" value=\"" +
                    req.getRequestURI() + "\">");
        out.println("<param name=\"id\" value=\"" +
                    session.getId() + "\">");
        out.println("</applet>");
        out.println("</center></body></html>");
    }

    /**
     * Validates the username and password
     * @param username The user name
     * @param password The user password
     * @return true if the username/password is valid
     */
    protected boolean validUser(String username, String password)
    {
        boolean valid = false;

        // Perform a simple check to make sure the user is valid.
        if ((username != null) && (username.length() > 0))
        {
            valid = username.equals(password);
        }

        return valid;
    }
}

