/*
 * LoginApplet
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 22, 2001
 */

package com.omh.security;

import java.applet.*;
import java.awt.*;
import java.io.*;
import java.net.*;

/**
 * This applet gathers a username and password and
 * then passes the information to a servlet to be
 * validated. If valid the servlet will send back the
 * location of the next page to be displayed. This
 * applet can be used with JDK 1.0.2 clients.
 */
public class LoginApplet
    extends Applet
{
    // Define the GUI widgets
    TextField username;
    TextField password;
    Label message;
    Button login;
    String codeBase;
    String servlet;
    String nextDoc;
    String sessionId;

    /**
     * Initialize the applet
     */
    public void init()
    {
        // Get the servlet name that will be validating
        // the username and password
        codeBase = "" + getCodeBase();
        servlet = getParameter("servlet");

        // Make sure we don't end up with a double '/'
        if (servlet != null)
        {
            if (servlet.startsWith("/") &&
                codeBase.endsWith("/"))
            {
                codeBase = codeBase.substring(0,
                            codeBase.length() - 1);
            }
        }

        // Get the session ID. This is a workaround for a
        // problem where the session ID of the original GET
        // is different than the session ID of our POST when
        // using URLConnection
        sessionId = getParameter("id");

        // Set our background color to blend in with a white
        // page
        setBackground(Color.white);

        // Set the layout to be a border layout. Place the message
        // area in the north, the login button in the south, and
        // the input areas in the center
        setLayout(new BorderLayout(0, 5));

        // Add the message area
        message = new Label();
        add("North", message);

        // Create the container for the input fields
        Panel p = new Panel();
        p.setLayout(new GridLayout(2, 2, 30, 20));

        // Add the username label and entry field
        p.add(new Label("Enter user name:"));
        username = new TextField(10);
        p.add(username);

        // Add the password label and entry field
        p.add(new Label("Enter password:"));
        password = new TextField(10);
        password.setEchoCharacter('*');
        p.add(password);

        add("Center", p);

        // Add the login button
        login = new Button("Login");
        add("South", login);

    }

    /**
     * Handle events
     */
    public boolean handleEvent(Event event)
    {
        if ((event != null) && (event.id == event.ACTION_EVENT))
        {
            if (event.target == login)
            {

                message.setText("");

                // Get the user and password
                String user = username.getText();
                String pw = password.getText();

                // May want to decrypt the user and/or password here

                // Validate the user. If the user is valid the
                // applet will show a new page; otherwise we'll
                // return back here
                boolean valid = false;
                try
                {
                    valid = validate(user, pw);
                }
                catch (Exception ex)
                {
                    ex.printStackTrace();
                }

                // Display a message for invalid users
                if (!valid)
                {
                    message.setText("Invalid user - please try again");
                }
                else
                {

                    // Show a new document
                    try
                    {
                        URL url = new URL(nextDoc);
                        System.out.println("showing " + url);
                        getAppletContext().showDocument(url);
                    }
                    catch (Exception ex)
                    {
                        message.setText("Invalid document: " + nextDoc);
                        ex.printStackTrace();
                    }
                }
            }
        }
        return false;
    }

    /**
     * Validate the user and password. This routine will
     * communicate with a servlet that does the validation
     * @param user User name
     * @param pw Password
     * @return true if the user is valid
     */
    protected boolean validate(String user, String pw)
      throws Exception
    {
        boolean valid = false;

        // Get the server URL
        java.net.URL url = new java.net.URL(codeBase + servlet);

        // Attempt to connect to the host
        java.net.URLConnection con = url.openConnection();

        // Initialize the connection
        con.setUseCaches(false);
        con.setDoOutput(true);
        con.setDoInput(true);

        // Data will always be written to a byte array buffer so
        // that we can tell the server the length of the data
        ByteArrayOutputStream byteOut = new ByteArrayOutputStream();

        // Create the output stream to be used to write the
        // data to our buffer
        DataOutputStream out = new DataOutputStream(byteOut);

        // Send the proper session id
        out.writeUTF(sessionId);

        // Send the username and password
        out.writeUTF(user);
        out.writeUTF(pw);

        // Flush the data to the buffer
        out.flush();

        // Get our buffer to be sent
        byte buf[] = byteOut.toByteArray();

        // Set the content that we are sending
        con.setRequestProperty("Content-type",
            "application/octet-stream");

        // Set the length of the data buffer we are sending
        con.setRequestProperty("Content-length",
            "" + buf.length);

        // Get the output stream to the server and send our
        // data buffer
        DataOutputStream dataOut =
            new DataOutputStream(con.getOutputStream());
        dataOut.write(buf);

        // Flush the output stream and close it
        dataOut.flush();
        dataOut.close();

        // Get the input stream we can use to read the response
        DataInputStream in =
            new DataInputStream(con.getInputStream());

        // Read the response from the server
        valid = in.readBoolean();
        System.out.println("valid user=" + valid);

        // If the user is valid get the name of the next
        // document to display
        if (valid)
        {
            nextDoc = in.readUTF();
            System.out.println("next document=" + nextDoc);
        }

        // Close the input stream
        in.close();
        return valid;
    }
}
