/*
 * Cookies
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 18, 2001
 */

package com.omh.session;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;
import java.io.PrintWriter;

public class Cookies
        extends HttpServlet
{
    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, IOException
    {

        // Set the content type of the response
        resp.setContentType("text/html");

        // Get the session. This will force a cookie
        // to be created
        req.getSession();

        // Get the PrintWriter to write the response
        PrintWriter out = resp.getWriter();

        // Get an array containing all of the cookies
        Cookie cookies[] = req.getCookies();

        // Write the page header
        out.println("<html>");
        out.println("<head>");
        out.println("<title>Servlet Cookie Information</title>");
        out.println("</head>");
        out.println("<body>");

        if ((cookies == null) || (cookies.length == 0)) {
            out.println("<center><h1>No Cookies found</h1>");
        }
        else {

            out.println("<center><h1>Cookies found</h1>");

            // Display a table with all of the info
            out.println("<table border>");
            out.println("<tr><th>Name</th><th>Value</th>" +
            "<th>Comment</th><th>Max Age</th></tr>");

            for (int i = 0; i < cookies.length; i++) {
                Cookie c = cookies[i];
                out.println("<tr><td>" + c.getName() +
                        "</td><td>" +
                        c.getValue() + "</td><td>" +
                        c.getComment() + "</td><td>" +
                        c.getMaxAge() + "</td></tr>");
            }

            out.println("</table></center>");
        }

        // Wrap up
        out.println("</body>");
        out.println("</html>");
        out.flush();
    }
}
