/*
 * CounterRewrite
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 18, 2001
 */

package com.omh.session;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;
import java.io.PrintWriter;

public class CounterRewrite
        extends HttpServlet
{

    // Define our counter key into the session
    static final String COUNTER_KEY = "Counter.count";

    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, IOException
    {

        // Get the session object for this client session.
        // The parameter indicates to create a session
        // object if one does not exist
        HttpSession session = req.getSession(true);

        // Set the content type of the response
        resp.setContentType("text/html");

        // Get the PrintWriter to write the response
        PrintWriter out = resp.getWriter();

        // Is there a count yet?
        int count = 1;
        Integer i = (Integer) session.getAttribute(COUNTER_KEY);

        // If a previous count exists, set it
        if (i != null) {
            count = i.intValue() + 1;
        }

        // Put the count back into the session
        session.setAttribute(COUNTER_KEY, new Integer(count));

        // Print a standard header
        out.println("<html>");
        out.println("<head>");
        out.println("<title>Session Counter</title>");
        out.println("</head>");
        out.println("<body>");
        out.println("Your session ID is <b>" +
        session.getId());
        out.println("</b> and you have hit this page <b>" +
                    count +
                    "</b> time(s) during this browser session");

        String url = req.getRequestURI();
        out.println("<form method=GET action=\"" +
                    resp.encodeURL(url) + "\">");
                    out.println("<input type=submit " +
                    "value=\"Hit page again\">");
                    out.println("</form>");

        // Wrap up
        out.println("</body>");
        out.println("</html>");
        out.flush();
    }
}
