/*
 * CounterServer
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 18, 2001
 */

package com.omh.session;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.IOException;
import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;

public class CounterServer
        extends HttpServlet
{
    // Define our counter key into the session
    static final String COUNTER_KEY = "CounterServer.count";

    public void doPost(HttpServletRequest req,
                       HttpServletResponse resp)
        throws ServletException, IOException
    {
        // Get the session
        HttpSession session = req.getSession(true);

        // Is there a count yet?
        int count = 1;
        Integer i = (Integer) session.getAttribute(COUNTER_KEY);

        // If a previous count exists, set it
        if (i != null) {
            count = i.intValue() + 1;
        }

        // Put the count back into the session
        session.setAttribute(COUNTER_KEY, new Integer(count));

        // Get the input stream for reading data from the client
        DataInputStream in =
            new DataInputStream(req.getInputStream());

        // We'll be sending binary data back to the client so
        // set the content type appropriately
        resp.setContentType("application/octet-stream");

        // Data will always be written to a byte array buffer so
        // that we can tell the client the length of the data
        ByteArrayOutputStream byteOut = new ByteArrayOutputStream();

        // Create the output stream to be used to write the
        // data to our buffer
        DataOutputStream out = new DataOutputStream(byteOut);

        // If there is any data being sent from the client,
        // read it here

        // Write the data to our internal buffer.
        out.writeInt(count);

        // Flush the contents of the output stream to the
        // byte array
        out.flush();

        // Get the buffer that is holding our response
        byte[] buf = byteOut.toByteArray();

        // Notify the client how much data is being sent
        resp.setContentLength(buf.length);

        // Send the buffer to the client
        ServletOutputStream servletOut = resp.getOutputStream();

        // Wrap up
        servletOut.write(buf);
        servletOut.close();
    }
}

