/*
 * StockServlet
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Oct 25, 2001
 */

package com.omh.stocks;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.*;

public class StockServlet
        extends HttpServlet
{
    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, java.io.IOException
    {
        PrintWriter out = resp.getWriter();

        // Get the symbols parameter. If missing, default
        // to the DOW and NASDAQ
        String symbols = req.getParameter("symbols");
        if (symbols == null)
        {
            symbols = "^DJI,^IXIC";
        }

        // Convert the comma-separated list of stock
        // symbols into a String[]
        StringTokenizer st = new StringTokenizer(symbols, ",");
        String[] symbolArray = new String[st.countTokens()];
        int i = 0;
        while (st.hasMoreElements())
        {
            String symbol = (String) st.nextElement();
            symbolArray[i++] = symbol;
        }

        // Get the info
        try
        {
            StockObject[] stocks =
                StockReader.getStockInfo(symbolArray);

            // Format the stock output as an XML document
            out.println("<?xml version=\"1.0\" ?>");
            out.println("<stock-quotes>");
            for (i = 0; i < stocks.length; i++)
            {
                StockObject o = stocks[i];
                outputStock(o, out);
            }
            out.println("</stock-quotes>");
        }
        catch (Exception ex)
        {
            throw new ServletException(ex.getMessage(), ex);
        }

    }

    public void doPost(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, java.io.IOException
    {
        // POST is the same as GET
        doGet(req, resp);
    }

    /*
     * Outputs a single stock
     */
    protected void outputStock(StockObject so, PrintWriter out)
    {
        out.println(" <stock>");
        outputElement("symbol", so.getSymbol(), out);
        outputElement("company-name", so.getCompanyName(), out);
        outputElement("last-trade-date", so.getLastTradeDate(), out);
        outputElement("last-trade-time", so.getLastTradeTime(), out);
        outputElement("price", so.getPrice(), out);
        outputElement("change-amount", so.getChange(), out);
        outputElement("open-price", so.getOpenPrice(), out);
        outputElement("high-price", so.getHighPrice(), out);
        outputElement("low-price", so.getLowPrice(), out);
        outputElement("volume", so.getVolume(), out);
        out.println(" </stock>");
    }

    /*
     * Outputs a single stock element
     */
    protected void outputElement(String name, String data, PrintWriter out)
    {
        // Use a StringBuffer - much more efficient
        StringBuffer sb = new StringBuffer("  <");
        sb.append(name);
        sb.append(">");
        sb.append(data);
        sb.append("</");
        sb.append(name);
        sb.append(">");
        out.println(sb.toString());
    }
}
