/*
 * Indy
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import java.sql.*;

/**
 * Implements the IndyInterface to provide query capabilities
 * into the Indianapolis 500 database.
 */
public class Indy implements IndyInterface
{
    // The JDBC Connection
    Connection connection = null;

    // A prepared statement to use to query the database
    PreparedStatement prepStmt = null;

    public boolean connect()
    {
        boolean rc = false;

        try
        {
            // Load the Bridge
            Class.forName("sun.jdbc.odbc.JdbcOdbcDriver").newInstance();

            // Connect to the Access database
            connection =
                DriverManager.getConnection("jdbc:odbc:MyAccessDataSource");

            // Go ahead and create a prepared statement
            prepStmt = connection.prepareStatement(
                "SELECT Year, Driver, AvgSpeed from IndyWinners " +
                "WHERE Year = ?");

            rc = true;
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }

        return rc;
    }

    public void close()
    {
        // Close the connection if it was opened
        if (connection != null)
        {
            try
            {
                connection.close();
            }
            catch (SQLException ex)
            {
                ex.printStackTrace();
            }
            connection = null;
        }
    }

    public IndyRecord query(int year)
    {
        IndyRecord record = null;

        try
        {
            // Set the year parameter
            prepStmt.setInt(1, year);

            // Execute the query
            ResultSet rs = prepStmt.executeQuery();

            // Make sure a record exists
            if (rs.next())
            {
                // Create a new IndyRecord object
                record = new IndyRecord();

                // Set the values
                record.year = rs.getInt(1);
                record.driver = rs.getString(2);
                record.speed = rs.getDouble(3);
            }
            rs.close();
        }
        catch (SQLException ex)
        {
            ex.printStackTrace();
            record = null;
        }

        return record;
    }
}
