/*
 * IndyApplet
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import java.applet.*;
import java.awt.*;
import java.awt.event.*;

/**
 * This applet demonstrates how to use the tunnel clients
 * to perform remote method calls using serialization
 */
public class IndyApplet
    extends Applet
    implements ActionListener
{
    // Define our global components
    TextField year = new TextField(10);
    TextField driver = new TextField(20);
    TextField speed = new TextField(10);
    Button query = new Button("Query");
    IndyInterface indy;

    /**
     * Initialize the applet
     */
    public void init()
    {
        // Don't allow the results to be edited
        driver.setEditable(false);
        speed.setEditable(false);

        // Use a grid bag layout
        GridBagLayout gridbag = new GridBagLayout();
        GridBagConstraints gbcon = new GridBagConstraints();
        setLayout(gridbag);

        // Setup the reusable constraint
        gbcon.weightx = 1.0;
        gbcon.weighty = 0.0;
        gbcon.anchor = gbcon.CENTER;
        gbcon.fill = gbcon.NONE;
        gbcon.gridwidth = gbcon.REMAINDER;

        // Add listeners
        query.addActionListener(this);

        // Add the components
        add(new Label("Enter the year:"));
        gridbag.setConstraints(year, gbcon);
        add(year);

        add(new Label("Press to query:"));
        gridbag.setConstraints(query, gbcon);
        add(query);

        add(new Label("Driver(s):"));
        gridbag.setConstraints(driver, gbcon);
        add(driver);

        add(new Label("Average Speed:"));
        gridbag.setConstraints(speed, gbcon);
        add(speed);

        // Create an instance of our remote object
        try
        {
            indy = new RemoteIndyClient(getCodeBase() + "/");

            // Open the database connection
            boolean rc = indy.connect();
            if (!rc)
            {
                System.out.println("Connection not initialized");
                indy = null;
            }
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Called when the applet is being destroyed
     */
    public void destroy()
    {
        // If the remote object was created close the connection
        if (indy != null)
        {
            indy.close();
            indy = null;
        }
    }

    /**
     * Process an action
     */
    public void actionPerformed(ActionEvent event)
    {
        Object o = event.getSource();

        // Figure out which component caused the event
        if (o == query)
        {
            // If the indy object was not created, get out
            if (indy == null)
            {
                return;
            }

            // Clear the display fields
            driver.setText("");
            speed.setText("");

            // Get the year entered by the user
            int n = 0;
            try
            {
                n = Integer.parseInt(year.getText());
            }
            catch (Exception ex)
            {
            }

            // Get the indy record
            IndyRecord r = indy.query(n);

            // Populate
            if (r != null)
            {
                driver.setText(r.driver);
                speed.setText("" + r.speed);
            }
        }
    }
}
