/*
 * MathLiteApplet
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import java.applet.*;
import java.awt.*;

/**
 * This calculator applet demonstrates how to use the
 * tunnel clients to perform remote method calls using
 * JDK 1.0.2 style events.
 */

public class MathLiteApplet
        extends Applet
{
    // Define the GUI widgets
    TextField output;
    Button b0;
    Button b1;
    Button b2;
    Button b3;
    Button b4;
    Button b5;
    Button b6;
    Button b7;
    Button b8;
    Button b9;
    Button dot;
    Button mult;
    Button add;
    Button sub;
    Button div;
    Button equals;
    Button clear;

    // Our memory area
    double mem;
    int opType;
    boolean newOp = false;

    // Operation types
    public static final int NONE = 0;
    public static final int MULTIPLY = 1;
    public static final int ADD = 2;
    public static final int SUBTRACT = 3;

    // Interface to our remote object
    MathInterface math;

    /**
     * Initialize the applet
     */
    public void init()
    {
        setLayout(new BorderLayout(0, 5));

        // Create the output text area for the amount
        output = new TextField("0");
        output.disable();
        add("North", output);

        // Create the container for the buttons
        Panel p = new Panel();
        p.setLayout(new GridLayout(4, 4, 3, 3));

        b0 = new Button("0");
        b1 = new Button("1");
        b2 = new Button("2");
        b3 = new Button("3");
        b4 = new Button("4");
        b5 = new Button("5");
        b6 = new Button("6");
        b7 = new Button("7");
        b8 = new Button("8");
        b9 = new Button("9");
        dot = new Button(".");
        mult = new Button("X");
        add = new Button("+");
        sub = new Button("-");
        div = new Button("/");
        equals = new Button("=");
        clear = new Button("C");

        // First row   7 8 9 +
        p.add(b7);
        p.add(b8);
        p.add(b9);
        p.add(add);

        // Second row  4 5 6 -
        p.add(b4);
        p.add(b5);
        p.add(b6);
        p.add(sub);

        // Third row   3 2 1 X
        p.add(b1);
        p.add(b2);
        p.add(b3);
        p.add(mult);

        // Fourth row  0 . C =
        p.add(b0);
        p.add(dot);
        p.add(clear);
        p.add(equals);

        add("Center", p);

        // Create an instance of our remote object
        try
        {
            math = new RemoteMathLiteClient(getCodeBase() + "/");
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    /**
     * Handle events
     */
    public boolean handleEvent(Event event)
    {
        if ((event != null) && (event.id == event.ACTION_EVENT))
        {
            if (event.target == b0)
            {
                append("0");
            }
            else if (event.target == b1)
            {
                append("1");
            }
            else if (event.target == b2)
            {
                append("2");
            }
            else if (event.target == b3)
            {
                append("3");
            }
            else if (event.target == b4)
            {
                append("4");
            }
            else if (event.target == b5)
            {
                append("5");
            }
            else if (event.target == b6)
            {
                append("6");
            }
            else if (event.target == b7)
            {
                append("7");
            }
            else if (event.target == b8)
            {
                append("8");
            }
            else if (event.target == b9)
            {
                append("9");
            }
            else if (event.target == dot)
            {
                append(".");
            }
            else if (event.target == mult)
            {
                compute(MULTIPLY);
            }
            else if (event.target == add)
            {
                compute(ADD);
            }
            else if (event.target == sub)
            {
                compute(SUBTRACT);
            }
            else if (event.target == equals)
            {
                compute();
            }
            else if (event.target == clear)
            {
                output.setText("0");
                mem = 0;
                opType = NONE;
            }
        }
        return false;
    }

    /**
     * Append the given number to the output text
     */
    protected void append(String s)
    {
        // If this is the first value after an operation, clear
        // the old value
        if (newOp)
        {
            newOp = false;
            output.setText("");
        }

        String o = output.getText();

        // Make sure it can fit
        if (o.length() >= 12)
        {
            return;
        }

        // First check if there is a decimal. If so, just tack
        // the string on the end
        if (o.indexOf(".") >= 0)
        {
            o += s;
        }
        else
        {
            // Otherwise check to see if the number is zero. If
            // it is, set the text to the given string
            if (o.equals("0"))
            {
                o = s;
            }
            else
            {
                o += s;
            }
        }

        output.setText(o);
    }

    /**
     * Compute the result
     */
    protected void compute()
    {
        double current =
            Double.valueOf(output.getText()).doubleValue();

        switch (opType)
        {

        case MULTIPLY:
            if (math != null)
            {
                mem = math.multiply(mem, current);
            }
            break;

        case ADD:
            if (math != null)
            {
                mem = math.add(mem, current);
            }
            break;

        case SUBTRACT:
            if (math != null)
            {
            mem = math.subtract(mem, current);
            }
            break;

        default:
            mem = current;
            break;
        }

        opType = NONE;

        String s = "" + mem;

        // Truncate if a whole number
        if (s.endsWith(".0"))
        {
            s = s.substring(0, s.length() - 2);
        }
        output.setText(s);
    }

    protected void compute(int type)
    {
        // If there is a current operation, execute it
        if (opType != NONE)
        {
            compute();
        }
        else
        {
            mem = Double.valueOf(output.getText()).doubleValue();
        }

        opType = type;
        newOp = true;
    }
}
