/*
 * RemoteIndyClient
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import com.omh.tunnel.client.TunnelClient;
import com.omh.tunnel.client.TunnelException;

import java.io.*;

/**
 * This class implements the client for tunneling
 * calls to the Indy object.
 */
public class RemoteIndyClient
    extends TunnelClient
    implements IndyInterface
{

    /**
     * Constructs a new RemoteMathLiteClient for the
     * given URL. The URL should contain the location of
     * servlet scripts (i.e. http://larryboy/servlet/).
     */
    public RemoteIndyClient(String url)
        throws TunnelException, IOException
    {
        // Append the remote server name
        if (!url.endsWith("/"))
        {
            url += "/";
        }
        url += "RemoteIndyServer";

        // Set the URL
        _setURL(new java.net.URL(url));

        // Initialize the client and server
        _initialize();
    }

    public boolean connect()
    {
        boolean rc = false;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an object stream to write the request
            ObjectOutputStream out =
                (ObjectOutputStream) _createHeader(baos, 0);

            // Invoke the method and read the response
            ObjectInputStream in =
                (ObjectInputStream) _invokeMethod(baos.toByteArray());

            // Read the return value
            Boolean b = (Boolean) in.readObject();
            rc = b.booleanValue();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }

        return rc;
    }

    public void close()
    {
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an object stream to write the request
            ObjectOutputStream out =
                (ObjectOutputStream) _createHeader(baos, 1);

            // Invoke the method
            _invokeMethod(baos.toByteArray());

            // Wrap up
            out.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }

    public IndyRecord query(int year)
    {
        IndyRecord record = null;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an object stream to write the request
            ObjectOutputStream out =
                (ObjectOutputStream) _createHeader(baos, 2);

            // Write the parameters
            out.writeObject(new Integer(year));

            // Invoke the method and read the response
            ObjectInputStream in =
                (ObjectInputStream) _invokeMethod(baos.toByteArray());

            // Read the return value
            record = (IndyRecord) in.readObject();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }

        return record;
    }
}
