/*
 * RemoteIndyServer
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import com.omh.tunnel.server.TunnelServer;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * This class implements the server for tunneling
 * remote Indy method calls
 */
public class RemoteIndyServer
    extends TunnelServer
{
    /**
     * Creates a new instance of the server object.
     *
     * @return Instance of the server object
     */
    public Object _getNewInstance()
        throws ServletException
    {
        return new Indy();
    }

    /**
     * Invokes the method for the ordinal given. If the method
     * throws an exception it will be sent to the client.
     *
     * @param Object Server object
     * @param ordinal Method ordinal
     * @param in Input stream to read additional parameters
     * @param out Output stream to write return values
     */
    public void _invokeMethod(Object serverObject, int ordinal,
                              DataInput in, DataOutput out)
        throws Exception
    {
        // Cast the server object
        Indy indy = (Indy) serverObject;

        // Cast the input/output streams
        ObjectInputStream objectIn = (ObjectInputStream) in;
        ObjectOutputStream objectOut = (ObjectOutputStream) out;

        // Evaluate the ordinal
        switch (ordinal)
        {

        case 0: // connect
            boolean b0 = indy.connect();
            objectOut.writeObject(new Boolean(b0));
            break;

        case 1: // close
            indy.close();
            break;

        case 2: // query
            Integer i2 = (Integer) objectIn.readObject();
            IndyRecord record = indy.query(i2.intValue());
            objectOut.writeObject(record);
            break;

        default:
            throw new Exception("Invalid ordinal: " + ordinal);
        }
    }
}
