/*
 * RemoteMathLiteClient
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import com.omh.tunnel.client.TunnelLiteClient;
import com.omh.tunnel.client.TunnelException;

import java.io.*;

/**
 * This class implements the 'lite' client for tunneling
 * calls to the Math object.
 */
public class RemoteMathLiteClient
    extends TunnelLiteClient
    implements MathInterface
{

    /**
     * Constructs a new RemoteMathLiteClient for the
     * given URL. The URL should contain the root location of
     * the servlet that will be invoked (i.e. http://larryboy/).
     */
    public RemoteMathLiteClient(String url)
        throws TunnelException, IOException
    {
        // Append the remote 'lite' server name
        if (!url.endsWith("/"))
        {
            url += "/";
        }
        url += "RemoteMathLiteServer";

        // Set the URL
        _setURL(new java.net.URL(url));

        // Initialize the client and server
        _initialize();
    }

    /**
     * Adds two numbers
     */
    public double add(double a, double b)
    {
        double n = 0;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an output stream to write the request
            DataOutputStream out =
                (DataOutputStream) _createHeader(baos, 0);

            // Output the parameters
            out.writeDouble(a);
            out.writeDouble(b);

            // Invoke the method and read the response
            DataInputStream in =
                (DataInputStream) _invokeMethod(baos.toByteArray());

            // Read the return value
            n = in.readDouble();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
        return n;
    }

    /**
     * Subtracts two numbers
     */
    public double subtract(double a, double b)
    {
        double n = 0;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an output stream to write the request
            DataOutputStream out =
                (DataOutputStream) _createHeader(baos, 1);

            // Output the parameters
            out.writeDouble(a);
            out.writeDouble(b);

            // Invoke the method and read the response
            DataInputStream in =
                (DataInputStream) _invokeMethod(baos.toByteArray());

            // Read the return value
            n = in.readDouble();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
        return n;
    }

    /**
     * Multiplies two numbers
     */
    public double multiply(double a, double b)
    {
        double n = 0;
        try
        {
            // Create an internal buffer
            ByteArrayOutputStream baos = new ByteArrayOutputStream();

            // Create an output stream to write the request
            DataOutputStream out =
                (DataOutputStream) _createHeader(baos, 2);

            // Output the parameters
            out.writeDouble(a);
            out.writeDouble(b);

            // Invoke the method and read the response
            DataInputStream in =
                (DataInputStream) _invokeMethod(baos.toByteArray());

            // Read the return value
            n = in.readDouble();

            // Wrap up
            out.close();
            in.close();
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
        return n;
    }
}
