/*
 * RemoteMathLiteServer
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import com.omh.tunnel.server.TunnelLiteServer;
import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * This class implements the 'lite' server for tunneling
 * remote Math method calls
 */
public class RemoteMathLiteServer
    extends TunnelLiteServer
{
    /**
     * Creates a new instance of the server object.
     *
     * @return Instance of the server object
     */
    public Object _getNewInstance()
        throws ServletException
    {
        return new Math();
    }

    /**
     * Invokes the method for the ordinal given. If the method
     * throws an exception it will be sent to the client.
     *
     * @param Object Server object
     * @param ordinal Method ordinal
     * @param in Input stream to read additional parameters
     * @param out Output stream to write return values
     */
    public void _invokeMethod(Object serverObject, int ordinal,
                              DataInput in, DataOutput out)
        throws Exception
    {
        // Cast the server object
        Math math = (Math) serverObject;

        // Cast the input/output streams
        DataInputStream dataIn = (DataInputStream) in;
        DataOutputStream dataOut = (DataOutputStream) out;

        // Evaluate the ordinal
        switch (ordinal)
        {

        case 0: // add
            double a0 = dataIn.readDouble();
            double b0 = dataIn.readDouble();
            double n0 = math.add(a0, b0);
            out.writeDouble(n0);
            break;

        case 1: // subtract
            double a1 = dataIn.readDouble();
            double b1 = dataIn.readDouble();
            double n1 = math.subtract(a1, b1);
            out.writeDouble(n1);
            break;

        case 2: // multiply
            double a2 = dataIn.readDouble();
            double b2 = dataIn.readDouble();
            double n2 = math.multiply(a2, b2);
            out.writeDouble(n2);
            break;

        default:
            throw new Exception("Invalid ordinal: " + ordinal);
        }
    }
}
