/*
 * TestObjectStream
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 25, 2001
 */

package com.omh.tunnel;

import java.io.*;

/**
 * This application shows how to read data from and write data
 * to a servlet using object input/output streams.
 */
public class TestObjectStream
{
    /**
     * Application entry point. This application requires
     * one parameter, which is the servlet URL
     */
    public static void main(String args[])
    {
        // Make sure we have an argument for the servlet URL
        if (args.length == 0)
        {
            System.out.println("\nServlet URL must be specified");
            return;
        }

        try
        {

            System.out.println("Attempting to connect to " + args[0]);

            // Get the server URL
            java.net.URL url = new java.net.URL(args[0]);

            // Attempt to connect to the host
            java.net.URLConnection con = url.openConnection();

            // Initialize the connection
            con.setUseCaches(false);
            con.setDoOutput(true);
            con.setDoInput(true);

            // Data will always be written to a byte array buffer so
            // that we can tell the server the length of the data
            ByteArrayOutputStream byteOut = new ByteArrayOutputStream();

            // Create the output stream to be used to write the
            // data to our buffer
            ObjectOutputStream out = new ObjectOutputStream(byteOut);

            System.out.println("Writing test objects");

            // Write the test data
            out.writeObject(new Boolean(true));
            out.writeObject(new Byte((byte) 1));
            out.writeObject(new Character((char) 2));
            out.writeObject(new Short((short) 3));
            out.writeObject(new Integer(4));
            out.writeObject(new Float(5));
            out.writeObject(new Double(6));
            out.writeObject("Hello, Karl");

            // Flush the data to the buffer
            out.flush();

            // Get our buffer to be sent
            byte buf[] = byteOut.toByteArray();

            // Set the content that we are sending
            con.setRequestProperty("Content-type",
                    "application/octet-stream");

            // Set the length of the data buffer we are sending
            con.setRequestProperty("Content-length",
                    "" + buf.length);

            // Get the output stream to the server and send our
            // data buffer
            DataOutputStream dataOut =
                new DataOutputStream(con.getOutputStream());
            //out.write(buf, 0, buf.length);
            dataOut.write(buf);

            // Flush the output stream and close it
            dataOut.flush();
            dataOut.close();

            System.out.println("Reading response");

            // Get the input stream we can use to read the response
            ObjectInputStream in =
                new ObjectInputStream(con.getInputStream());

            // Read the data from the server
            Boolean booleanValue = (Boolean) in.readObject();
            Byte byteValue = (Byte) in.readObject();
            Character charValue = (Character) in.readObject();
            Short shortValue = (Short) in.readObject();
            Integer intValue = (Integer) in.readObject();
            Float floatValue = (Float) in.readObject();
            Double doubleValue = (Double) in.readObject();
            String stringValue = (String) in.readObject();

            // Close the input stream
            in.close();

            System.out.println("Data read: " +
                    booleanValue + " " +
                    byteValue + " " +
                    ((int) charValue.charValue()) + " " +
                    shortValue + " " +
                    intValue + " " +
                    floatValue + " " +
                    doubleValue + " " +
                    stringValue);
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }

    }
}
