/*
 * TunnelClient
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 24, 2001
 */

package com.omh.tunnel.client;

import java.io.*;

/**
 * This class implements the necessary TunnelClientInterface
 * methods for a JDK 1.1 tunneled client. The marshaling of
 * data is done with serialization.
 */
public abstract class TunnelClient
        extends BaseTunnelClient
{
    /**
     * Gets an input stream to be used for reading data
     * from the connection. The lite version uses a standard
     * data input stream for reading data.
     *
     * @param in Input stream from the connection URL
     * @return Input stream to read data from the connection
     */
    public DataInput _getInputStream(InputStream in)
        throws IOException
    {
        // Create a new DataInputStream for reading data from
        // the connection.
        return new ObjectInputStream(in);
    }

    /**
     * Gets an output stream to be used for writing data to
     * an internal buffer. The buffer will be written to the
     * connection. The lite version uses a standard data
     * output stream for writing data.
     *
     * @param buffer Buffer to hold the output data
     * @return Output stream to write data to the buffer
     */
    public DataOutput _getOutputStream(ByteArrayOutputStream buffer)
        throws IOException
    {
        // Create a new DataOutputStream for writing data to
        // the buffer.
        return new ObjectOutputStream(buffer);
    }

    /**
     * Flushes the any buffered data to the output stream
     *
     * @param out Output stream to flush
     */
    public void _flush(DataOutput out) throws IOException
    {
        // Flush the data to the buffer
        ((ObjectOutputStream) out).flush();
    }

    /**
     * Closes the input stream
     *
     * @param in Input stream to close
     */
    public void _close(DataInput in) throws IOException
    {
        ((ObjectInputStream) in).close();
    }
}
