/*
 * TunnelLiteServer
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 *
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 24, 2001
 */

package com.omh.tunnel.server;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

/**
 * This is the base class to be extended by server objects
 * that are using HTTP lite tunneling.
 */
public abstract class TunnelLiteServer
        extends BaseTunnelServlet
{
    /**
     * Creates an input stream to be used to read data
     * sent from the client.
     *
     * @param servletInput Servlet input stream from the servlet
     * request header
     * @return Input stream to read data from the client
     */
    public DataInput _getInputStream(ServletInputStream servletInput)
        throws IOException
    {
        // Create a new DataInputStream for reading data from
        // the client.
        return new DataInputStream(servletInput);
    }

    /**
     * Gets an output stream to be used for writing data to
     * an internal buffer. The buffer will be written to the
     * client
     *
     * @param buffer Buffer to hold the output data
     * @return Output stream to write data to the buffer
     */
    public DataOutput _getOutputStream(ByteArrayOutputStream buffer)
        throws IOException
    {
        // Create a new DataOutputStream for writing data to
        // the buffer.
        return new DataOutputStream(buffer);
    }

    /**
     * Flushes the any buffered data to the output stream
     *
     * @param out Output stream to flush
     */
    public void _flush(DataOutput out) throws IOException
    {
        // Flush the data to the buffer
        ((DataOutputStream) out).flush();
    }
}

