/*
 * ErrorServlet
 *
 * Copyright (c) 1998-2002 Karl Moss. All Rights Reserved.
 * 
 * Developed in conjunction with the book "Java Servlets Developer's
 * Guide" published by McGraw-Hill/Osborne Media Group
 *
 * You may study, use, modify, and distribute this software for any
 * purpose.
 *
 * This software is provided WITHOUT WARRANTY either expressed or
 * implied.
 *
 * @author  Karl Moss
 * @date Nov 13, 2001
 */

package com.omh.webapps;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.*;

public class ErrorServlet
        extends HttpServlet
{
    public void doGet(HttpServletRequest req,
                      HttpServletResponse resp)
        throws ServletException, IOException
    {
        resp.setContentType("text/html");

        // Get an output stream that takes into account
        // the proper character encoding
        PrintWriter out = resp.getWriter();

        out.println("<html>");
        out.println("<head>");
        out.println("<title>Error Servlet");
        out.println("</title>");
        out.println("</head><body>");

        out.println("<center>The server has encountered an error!");
        out.println("<table border width=80%>");

        out.println("<tr><td>");
        out.println("Status code</td><td>");
        out.println(
                req.getAttribute("javax.servlet.error.status_code"));
        out.println("</td></tr>");

        out.println("<tr><td>");
        out.println("Request URI</td><td>");
        out.println(
                req.getAttribute("javax.servlet.error.request_uri"));
        out.println("</td></tr>");

        out.println("<tr><td>");
        out.println("Servlet name</td><td>");
        out.println(
                req.getAttribute("javax.servlet.error.servlet_name"));
        out.println("</td></tr>");

        out.println("<tr><td>");
        out.println("Message</td><td>");
        out.println(
                req.getAttribute("javax.servlet.error.message"));
        out.println("</td></tr>");

        out.println("<tr><td>");
        out.println("Exception type</td><td>");
        out.println(
                req.getAttribute("javax.servlet.error.exception_type"));
        out.println("</td></tr>");

        out.println("<tr><td>");
        out.println("</table></center>");

        // Output the stack trace if possible
        Throwable t =
                (Throwable) req.getAttribute("javax.servlet.error.exception");
        String trace = getStackTrace(t);
        if (trace != null)
        {
            out.println("<br><br><dir><pre>");
            out.println(trace);
            out.println("</pre></dir>");
        }

        out.println("</body>");
        out.println("</html>");
        out.flush();
    }

    /**
     * Captures an exception stack trace in a String
     */
    public static String getStackTrace(Throwable t)
    {
        String s = null;
        if (t != null)
        {
            // Create a writer to send the stack trace to
            CharArrayWriter w = new CharArrayWriter();
            PrintWriter out = new PrintWriter(w);
            t.printStackTrace(out);
            s = w.toString();
        }
        return s;
    }

}
